import requests

def reload(token):
    response = requests.get(f'https://api.tigitaal.nl/user/reload/{token}')
    return response.json()

def reloadadvanced(username, password):
    response = requests.get(f'https://api.tigitaal.nl/user/reloadadvanced/{username}/{password}')
    return response.json()

# Buggy/doesnt work
def pfp(token, pfp):
    response = requests.post(f'https://api.tigitaal.nl/user/reload/{token}/{pfp}')
    return response.json()

def nickname(username, password, nickname):
    response = requests.post(f'https://api.tigitaal.nl/user/nickname/{username}/{password}/{nickname}')
    return response.json()

def mail(username, password, email):
    response = requests.post(f'https://api.tigitaal.nl/user/mail/{username}/{password}/{email}')
    return response.json()


from setuptools import setup, find_packages

VERSION = '0.0.3' 
DESCRIPTION = 'Tigitaal\'s Official Python Package to connect with TigitaalAPI'

# Setting up
setup(
        name="tigitaalconnect", 
        version=VERSION,
        author="Ninjagor",
        author_email="ninjagor.spoon@gmail.com",
        description=DESCRIPTION,
        long_description=open('README.txt').read() + '\n\n' + open('CHANGELOG.txt').read(),
        packages=find_packages(),
        install_requires=[
            'requests'
        ],
        
        keywords=['python', 'first package'],
        classifiers= [
            "Development Status :: 5 - Production/Stable",
            "Intended Audience :: Education",
            "Programming Language :: Python :: 3",
            "Operating System :: MacOS :: MacOS X",
            "Operating System :: Microsoft :: Windows",
        ]
)